@@ -12,7 +12,7 @@ use anyhow::{Context, Result, anyhow};
 use rustls_pemfile as pemfile;
 
 use crate::{
-    args::{CliArgs, MediaType, parse_auth},
+    args::{CliArgs, DuplicateFile, MediaType, parse_auth},
     auth::RequiredAuth,
     file_utils::sanitize_path,
     listing::{SortingMethod, SortingOrder},
@@ -122,8 +122,8 @@ pub struct MiniserveConfig {
     /// HTML accept attribute value
     pub uploadable_media_type: Option<String>,
 
-    /// Enable upload to override existing files
-    pub overwrite_files: bool,
+    /// What to do on upload if filename already exists
+    pub on_duplicate_files: DuplicateFile,
 
     /// If false, creation of uncompressed tar archives is disabled
     pub tar_enabled: bool,
@@ -324,7 +324,7 @@ impl MiniserveConfig {
             index: args.index,
             spa: args.spa,
             pretty_urls: args.pretty_urls,
-            overwrite_files: args.overwrite_files,
+            on_duplicate_files: args.on_duplicate_files,
             show_qrcode: args.qrcode,
             directory_size: args.directory_size,
             mkdir_enabled: args.mkdir_enabled,
