@@ -27,8 +27,8 @@ use tokio::io::AsyncWriteExt;
 use tokio::sync::RwLock;
 
 use crate::{
-    config::MiniserveConfig, errors::RuntimeError, file_utils::contains_symlink,
-    file_utils::sanitize_path,
+    args::DuplicateFile, config::MiniserveConfig, errors::RuntimeError,
+    file_utils::contains_symlink, file_utils::sanitize_path,
 };
 
 enum FileHash {
@@ -67,24 +67,24 @@ pub async fn recursive_dir_size(dir: &Path) -> Result<u64, RuntimeError> {
     loop {
         match entries.next().await {
             Some(Ok(entry)) => {
-                if let Ok(metadata) = entry.metadata().await {
-                    if metadata.is_file() {
-                        // On Unix, we want to filter inodes that we've already seen so we get a
-                        // more accurate count of real size used on disk.
-                        #[cfg(target_family = "unix")]
-                        {
-                            let (device_id, inode) = (metadata.dev(), metadata.ino());
+                if let Ok(metadata) = entry.metadata().await
+                    && metadata.is_file()
+                {
+                    // On Unix, we want to filter inodes that we've already seen so we get a
+                    // more accurate count of real size used on disk.
+                    #[cfg(target_family = "unix")]
+                    {
+                        let (device_id, inode) = (metadata.dev(), metadata.ino());
 
-                            // Check if this file has been seen before based on its device ID and
-                            // inode number
-                            if seen_inodes.read().await.contains(&(device_id, inode)) {
-                                continue;
-                            } else {
-                                seen_inodes.write().await.insert((device_id, inode));
-                            }
+                        // Check if this file has been seen before based on its device ID and
+                        // inode number
+                        if seen_inodes.read().await.contains(&(device_id, inode)) {
+                            continue;
+                        } else {
+                            seen_inodes.write().await.insert((device_id, inode));
                         }
-                        total_size += metadata.len();
                     }
+                    total_size += metadata.len();
                 }
             }
             Some(Err(e)) => {
@@ -109,13 +109,36 @@ pub async fn recursive_dir_size(dir: &Path) -> Result<u64, RuntimeError> {
 /// Returns total bytes written to file.
 async fn save_file(
     field: &mut actix_multipart::Field,
-    file_path: PathBuf,
-    overwrite_files: bool,
+    mut file_path: PathBuf,
+    on_duplicate_files: DuplicateFile,
     file_checksum: Option<&FileHash>,
     temporary_upload_directory: Option<&PathBuf>,
 ) -> Result<u64, RuntimeError> {
-    if !overwrite_files && file_path.exists() {
-        return Err(RuntimeError::DuplicateFileError);
+    if file_path.exists() {
+        match on_duplicate_files {
+            DuplicateFile::Error => return Err(RuntimeError::DuplicateFileError),
+            DuplicateFile::Overwrite => (),
+            DuplicateFile::Rename => {
+                // extract extension of the file and the file stem without extension
+                // file.txt => (file, txt)
+                let file_name = file_path.file_stem().unwrap_or_default().to_string_lossy();
+                let file_ext = file_path.extension().map(|s| s.to_string_lossy());
+                for i in 1.. {
+                    // increment the number N in {file_name}-{N}.{file_ext}
+                    // format until available name is found (e.g. file-1.txt, file-2.txt, etc)
+                    let fp = if let Some(ext) = &file_ext {
+                        file_path.with_file_name(format!("{file_name}-{i}.{ext}"))
+                    } else {
+                        file_path.with_file_name(format!("{file_name}-{i}"))
+                    };
+                    // If we have a file name that doesn't exist yet then we'll use that.
+                    if !fp.exists() {
+                        file_path = fp;
+                        break;
+                    }
+                }
+            }
+        }
     }
 
     let temp_upload_directory = temporary_upload_directory.cloned();
@@ -213,16 +236,16 @@ async fn save_file(
     // - https://github.com/actix/actix-web/discussions/3011
     // Therefore, we are relying on the fact that the web UI uploads a
     // hash of the file to determine if it was completed uploaded or not.
-    if let Some(hasher) = hasher {
-        if let Some(expected_hash) = file_checksum.as_ref().map(|f| f.get_hash()) {
-            let actual_hash = hex::encode(hasher.finalize());
-            if actual_hash != expected_hash {
-                warn!(
-                    "The expected file hash {expected_hash} did not match the calculated hash of {actual_hash}. This can be caused if a file upload was aborted."
-                );
-                let _ = tokio::fs::remove_file(&temp_path).await;
-                return Err(RuntimeError::UploadHashMismatchError);
-            }
+    if let Some(hasher) = hasher
+        && let Some(expected_hash) = file_checksum.as_ref().map(|f| f.get_hash())
+    {
+        let actual_hash = hex::encode(hasher.finalize());
+        if actual_hash != expected_hash {
+            warn!(
+                "The expected file hash {expected_hash} did not match the calculated hash of {actual_hash}. This can be caused if a file upload was aborted."
+            );
+            let _ = tokio::fs::remove_file(&temp_path).await;
+            return Err(RuntimeError::UploadHashMismatchError);
         }
     }
 
@@ -258,7 +281,7 @@ async fn save_file(
 }
 
 struct HandleMultipartOpts<'a> {
-    overwrite_files: bool,
+    on_duplicate_files: DuplicateFile,
     allow_mkdir: bool,
     allow_hidden_paths: bool,
     allow_symlinks: bool,
@@ -273,7 +296,7 @@ async fn handle_multipart(
     opts: HandleMultipartOpts<'_>,
 ) -> Result<u64, RuntimeError> {
     let HandleMultipartOpts {
-        overwrite_files,
+        on_duplicate_files,
         allow_mkdir,
         allow_hidden_paths,
         allow_symlinks,
@@ -390,7 +413,7 @@ async fn handle_multipart(
     save_file(
         &mut field,
         path.join(filename_path),
-        overwrite_files,
+        on_duplicate_files,
         file_hash,
         upload_directory,
     )
@@ -475,7 +498,7 @@ pub async fn upload_file(
                 field,
                 non_canonicalized_target_dir.clone(),
                 HandleMultipartOpts {
-                    overwrite_files: conf.overwrite_files,
+                    on_duplicate_files: conf.on_duplicate_files,
                     allow_mkdir: conf.mkdir_enabled,
                     allow_hidden_paths: conf.show_hidden,
                     allow_symlinks: !conf.no_symlinks,
